[![Build Status](https://travis-ci.com/donchesworth/dask-quik.svg?branch=main)](https://travis-ci.com/donchesworth/dask-quik)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)
[![code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![codecov](https://codecov.io/gh/donchesworth/dask-quik/branch/main/graph/badge.svg?token=U92M8C8AFM)](https://codecov.io/gh/donchesworth/dask-quik)

# dask-quik  <img src="dask-quik.png" align="right" width="120" />
Utilities for transforming data using dask and dask_cudf
